{pkgs, ...}: {
    xdg.portal = {
        enable = true;
        wlr.enable = true;
    };
    
    # Enable automatic login for the user.
    services = {
        # flatpak dev.deedles.Trayscale
        # sudo tailscale up --operator=$USER 
        # use https://hs.wetofu.me
        tailscale.enable = true;
        blueman.enable = true;
        logrotate.checkConfig = false;
        flatpak.enable = true;
        
        greetd = {
            enable = true;
            settings = rec {
                initial_session = {
                    user = "user";
                    command = "${pkgs.greetd.greetd}/bin/agreety --cmd Hyprland";
                };
                default_session = initial_session;
            };
        };

        xserver = {
            layout = "cn";
            xkbVariant = "";
            libinput = {
                mouse = {
                    accelProfile = "flat";
                };
            };
        };

        pipewire = {
            enable = true;
            alsa.enable = true;
            pulse.enable = true;
        };
    };

    # List packages installed in system profile. To search, run:
    # $ nix search wget
    environment.systemPackages = with pkgs; [
        hyprland-protocols
        hyprland-share-picker
        xdg-desktop-portal-hyprland
    ];
  
    programs = {
        hyprland = {
            enable = true;
            xwayland = {
                enable = true;
                hidpi = true;
            };
        };

        git.enable = true;
        zsh.enable = true;
        light.enable = true;
    };

    virtualisation = {
        podman.enable = true;
        oci-containers.backend = "podman";
        oci-containers.containers = {
            wsproxy = {
                login.username = "senseab";
                login.registry = "ghcr.io";
                login.passwordFile = "/var/lib/secrets/podman/ghcr.io";  # should create it manually.
                image = "ghcr.io/senseab/wsproxy:master";
                autoStart = true;

                environment = {
                    CONFIG_NO_TLS_VERIFY = "true";
                    CONFIG_ADDR = "wss://dev.wetofu.me/path";
                    WSPROXY_MODE = "client";
                };

                ports = [
                    "127.0.0.1:1089:1089"
                ];
            };
        };
    };
}